﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace TimeControlApp
{
    public partial class TimeControl : UserControl
    {
        private SolidColorBrush movingBrush;
        private SolidColorBrush defaultBrush;
        private MouseEventHandler drag;

        public TimeControl()
        {
            InitializeComponent();
            ShowLabel(0.0);
            defaultBrush = new SolidColorBrush(Colors.Blue);
            movingBrush = new SolidColorBrush(Color.FromArgb(255, 0, 0, 100));
            handleFill.Fill = defaultBrush;
            drag = new MouseEventHandler(handleFill_MouseMove);
        }

        private void handleFill_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            handleFill.Fill = movingBrush;
            handleFill.CaptureMouse();
            handle.MouseMove += drag;
        }

        private void handleFill_MouseLeftButtonUp(object sender, MouseButtonEventArgs e)
        {
            handle.MouseMove -= drag;
            handleFill.Fill = defaultBrush;
            handleFill.ReleaseMouseCapture();
        }

        private void handleFill_MouseMove(object sender, MouseEventArgs e)
        {
            if (handleFill.Fill == defaultBrush)
                return;
            Point p = e.GetPosition(root);
            Point o = new Point(root.ActualWidth / 2.0, root.ActualHeight);
            PolarPoint pp = new PolarPoint(p, o);
            if (pp.Radius < 200)
                return;
            double angle = 90.0 - (pp.Angle * 180.0 / Math.PI);
            if (angle < -85.0 || angle >= 180.0)
            {
                angle = -85.0;
            }
            else if (angle > 85.0)
            {
                angle = 85.0;
            }
            handleAngle.Angle = angle;
            ShowLabel(angle);
        }

        private void ShowLabel(double angle)
        {
            int seconds = (int)(angle * 400.0);
            TimeSpan ts = new TimeSpan(0, 0, seconds);
            DateTime dt = DateTime.Now;
            dt = new DateTime(dt.Year, dt.Month, dt.Day, 15, 0, 0).Add(ts);
            aLabel.Text = dt.ToString();
        }

        private void UserControl_LayoutUpdated(object sender, EventArgs e)
        {
            System.Windows.Interop.Content c = Application.Current.Host.Content;
            double w = c.ActualWidth;
            double h = c.ActualHeight;
            double sx = w / 660.0;
            double sy = h / 360.0;
            scale.ScaleX = sx;
            scale.ScaleY = sy;
        }
    }
}
